@@ -26,7 +26,8 @@ DEFAULT_SETTINGS = {
     "tray/minimize": True,
     "feeds/update_interval/minutes": 10,
     "feeds/refresh_entries": True,
-    "youtube/show_description": True,
+    "entry/show_description": True,
+    "entry/show_thumbnail": True,
     "player": "mpv",
     "player/mpv/path": "mpv",
     "player/mpv/args": "",
