@@ -90,8 +90,9 @@ class TreeWidgetItemCategory(QtWidgets.QTreeWidgetItem):
     def set_font(self):
         category_viewed = self.parent.feeds.get_category_viewed(self.category)
         font = QtGui.QFont()
-        font.setBold(not category_viewed)
-        font.setPointSize(8 if category_viewed else 10)
+        if not category_viewed:
+            font.setBold(True)
+            font.setPointSize(font.pointSize() + 1)
         self.setFont(0, font)
         self.setForeground(
             0,
@@ -152,8 +153,9 @@ class TreeWidgetItemFeed(QtWidgets.QTreeWidgetItem):
     def set_font(self):
         feed_viewed = self.parent.feeds.get_feed_viewed(self.feed_id)
         font = QtGui.QFont()
-        font.setBold(not feed_viewed)
-        font.setPointSize(8 if feed_viewed else 10)
+        if not feed_viewed:
+            font.setBold(True)
+            font.setPointSize(font.pointSize() + 1)
         self.setFont(0, font)
         self.setForeground(
             0,
@@ -238,8 +240,9 @@ class TreeWidgetItemStarred(QtWidgets.QTreeWidgetItem):
     def set_font(self):
         stars_viewed = self.parent.feeds.get_stars_viewed()
         font = QtGui.QFont()
-        font.setBold(not stars_viewed)
-        font.setPointSize(8 if stars_viewed else 10)
+        if not stars_viewed:
+            font.setBold(True)
+            font.setPointSize(font.pointSize() + 1)
         self.setFont(0, font)
         self.setForeground(
             0,
@@ -371,11 +374,9 @@ class MyTreeWidget(QtWidgets.QTreeWidget):
         self.set_tree_icons()
 
     def remove_category(self, category: str):
-        category_items = self.findItems(category, QtCore.Qt.MatchFlag.MatchExactly)
-        if not category_items:
-            return
-        category_item_to_remove = category_items[0]
-        self.takeTopLevelItem(self.indexOfTopLevelItem(category_item_to_remove))
+        for item in self.findItems(category, QtCore.Qt.MatchFlag.MatchExactly):
+            if isinstance(item, TreeWidgetItemCategory):
+                self.takeTopLevelItem(self.indexOfTopLevelItem(item))
 
     def remove_feed(self, feed_id: int):
         feed = self.feeds.get_feed(feed_id)
