@@ -9,8 +9,9 @@ from .PurgeEntriesDialog import PurgeEntriesDialog
 from .PurgeExcludeDialog import PurgeExcludeDialog
 from .ShortcutDialog import ShortcutsDialog
 from rss_tube.database.settings import Settings
+from rss_tube.database.feeds import Feeds
 from rss_tube.gui.themes import styles
-from rss_tube.utils import center_widget
+from rss_tube.utils import center_widget, open_file
 from rss_tube.utils import set_icons, set_style
 from rss_tube.tasks import ExportSettingsTask, ImportSettingsTask
 
@@ -53,7 +54,8 @@ class SettingsDialog(QtWidgets.QDialog, Ui_Dialog):
         self.combo_theme.setCurrentText(settings.value("theme", type=str))
 
         self.cb_show_menu.setChecked(settings.value("MainWindow/menu/show", type=bool))
-        self.cb_show_description.setChecked(settings.value("youtube/show_description", type=bool))
+        self.cb_show_description.setChecked(settings.value("entry/show_description", type=bool))
+        self.cb_show_thumbnail.setChecked(settings.value("entry/show_thumbnail", type=bool))
 
         self.cb_show_tray.setChecked(settings.value("tray/show", type=bool))
         self.cb_minimize_to_tray.setChecked(settings.value("tray/minimize", type=bool))
@@ -118,6 +120,10 @@ class SettingsDialog(QtWidgets.QDialog, Ui_Dialog):
         self.setting_theme_changed = True
         self.settings_changed_callback()
     
+    def unblacklist_callback(self):
+        feeds = Feeds()
+        feeds.unblacklist_purged_entries()
+    
     def purge_entries_callback(self):
         purge_entries_dialog = PurgeEntriesDialog(self)
         purge_entries_dialog.exec()
@@ -176,13 +182,14 @@ class SettingsDialog(QtWidgets.QDialog, Ui_Dialog):
 
         self.cb_show_menu.stateChanged.connect(self.settings_changed_callback)
         self.cb_show_description.stateChanged.connect(self.settings_changed_callback)
+        self.cb_show_thumbnail.stateChanged.connect(self.settings_changed_callback)
 
         self.cb_minimize_to_tray.stateChanged.connect(self.settings_changed_callback)
         self.cb_show_tray.stateChanged.connect(self.settings_changed_callback)
         self.cb_start_minimized.stateChanged.connect(self.settings_changed_callback)
 
         self.combo_logging.currentTextChanged.connect(self.settings_changed_callback)
-        self.pb_open_log.clicked.connect(self.mainwindow.open_log_callback)
+        self.pb_open_log.clicked.connect(lambda: open_file(logger.root.handlers[0].baseFilename))
 
         # Schedule Tab
         self.spin_update_feed_interval_minutes.valueChanged.connect(self.schedule_changed_callback)
@@ -197,6 +204,7 @@ class SettingsDialog(QtWidgets.QDialog, Ui_Dialog):
         # Database Tab
         self.cb_preload_thumbnails.stateChanged.connect(self.settings_changed_callback)
         self.spin_entries_to_fetch.valueChanged.connect(self.settings_changed_callback)
+        self.pb_unblacklist.clicked.connect(self.unblacklist_callback)
         self.pb_purge_entries.clicked.connect(self.purge_entries_callback)
         self.cb_purge_schedule.stateChanged.connect(self.settings_changed_callback)
         self.spin_entries_to_keep.valueChanged.connect(self.settings_changed_callback)
@@ -205,7 +213,7 @@ class SettingsDialog(QtWidgets.QDialog, Ui_Dialog):
         
         self.pb_reset_cache.clicked.connect(self.mainwindow.feeds.downloader.cache.clear)
 
-        self.pb_open_database.clicked.connect(self.mainwindow.open_database_callback)
+        self.pb_open_database.clicked.connect(lambda: open_file(self.mainwindow.feeds.database.dir))
 
         # Advanced tab
         self.pb_reset_settings.clicked.connect(self.reset_settings_callback)
@@ -236,8 +244,11 @@ class SettingsDialog(QtWidgets.QDialog, Ui_Dialog):
 
         settings.setValue("MainWindow/menu/show", self.cb_show_menu.isChecked())
         self.mainwindow.menubar.setVisible(settings.value("MainWindow/menu/show", type=bool))
-        settings.setValue("youtube/show_description", self.cb_show_description.isChecked())
-        self.mainwindow.entry_widgets["youtube"].show_description(settings.value("youtube/show_description", type=bool))
+        settings.setValue("entry/show_description", self.cb_show_description.isChecked())
+        settings.setValue("entry/show_thumbnail", self.cb_show_thumbnail.isChecked())
+        for widget in self.mainwindow.entry_widgets.values():
+            widget.show_description(settings.value("entry/show_description", type=bool))
+            widget.show_thumbnail(settings.value("entry/show_thumbnail", type=bool))
 
         settings.setValue("tray/show", self.cb_show_tray.isChecked())
         self.mainwindow.tray.setVisible(self.cb_show_tray.isChecked())
