@@ -2,12 +2,14 @@ from typing import Optional
 
 from .mpv import MpvPlayerInstance
 from .vlc import VlcPlayerInstance
+from .generic import GenericPlayerInstance
 from .base import BasePlayer
 
 
 _player_instances = {
     "mpv": MpvPlayerInstance,
-    "vlc": VlcPlayerInstance
+    "vlc": VlcPlayerInstance,
+    "generic": GenericPlayerInstance,
 }
 
 
